==> animalai-3.0.4.tar.gz: animalai-3.0.4/setup.py <==
from setuptools import setup, find_packages

setup(
    name="animalai",
    version="3.0.4",
    description="Animal AI 3 Python API",
    long_description= open('README.md').read(),
    long_description_content_type = 'text/markdown',
    url="https://github.com/Kinds-of-Intelligence-CFI/animalai-package",
    author="Matt Crosby; Ibrahim Alhas; Konstantinos Voudouris; Wout Schellaert; Joel Holmes; Ben Beyret",
    author_email="kindsofintelligence.cfi@gmail.com",
    classifiers=[
        "Intended Audience :: Developers",
        "Intended Audience :: Science/Research",
        "Topic :: Scientific/Engineering :: Artificial Intelligence",
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Operating System :: Microsoft :: Windows :: Windows 10",
        "Operating System :: Microsoft :: Windows :: Windows 11",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: POSIX :: Linux"
    ],
    project_urls={
        "Website": "https://sites.google.com/csah.cam.ac.uk/animalai",
        "Main Repository": "https://github.com/Kinds-of-Intelligence-CFI/animal-ai",
        "Releases": "https://github.com/Kinds-of-Intelligence-CFI/animal-ai/releases",#
        "Documentation": "https://github.com/Kinds-of-Intelligence-CFI/animal-ai/tree/main/docs"
    },
    packages=find_packages(exclude=["*.tests", "*.tests.*", "tests.*", "tests"]),
    zip_safe=False,
    install_requires=["mlagents==0.30.0",
                      "numpy==1.21.2",
                      "scipy==1.7.2",
                      "pandas== 1.3.2",
                      "protobuf== 3.20.3",
                      "stable-baselines3== 2.1.0",
                      "shimmy== 1.3.0",
                      "notebook"],
    python_requires=">=3.6, <3.10",
)

==> animalai-3.0.5.tar.gz: animalai-3.0.5/setup.py <==
from setuptools import setup, find_packages

setup(
    name="animalai",
    version="3.0.5",
    description="Animal AI 3 Python API",
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url="https://github.com/Kinds-of-Intelligence-CFI/animalai-package",
    author="Matt Crosby; Ibrahim Alhas; Konstantinos Voudouris; Wout Schellaert; Joel Holmes; Ben Beyret",
    author_email="kindsofintelligence.cfi@gmail.com",
    classifiers=[
        "Intended Audience :: Developers",
        "Intended Audience :: Science/Research",
        "Topic :: Scientific/Engineering :: Artificial Intelligence",
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Operating System :: Microsoft :: Windows :: Windows 10",
        "Operating System :: Microsoft :: Windows :: Windows 11",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: POSIX :: Linux",
    ],
    project_urls={
        "Website": "https://sites.google.com/csah.cam.ac.uk/animalai",
        "Main Repository": "https://github.com/Kinds-of-Intelligence-CFI/animal-ai",
        "Releases": "https://github.com/Kinds-of-Intelligence-CFI/animal-ai/releases",
        "Documentation": "https://github.com/Kinds-of-Intelligence-CFI/animal-ai/tree/main/docs",
    },
    packages=find_packages(exclude=["*.tests", "*.tests.*", "tests.*", "tests"]),
    zip_safe=False,
    install_requires=[
        "mlagents==0.30.0",
        "protobuf==3.20.3",
        "numpy==1.21.2",
    ],
    python_requires=">=3.6, <3.10",
)
